.. goodlog documentation master file, created by
   sphinx-quickstart.

Welcome to goodlog's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

